compute method

  1. @override
T compute(
  1. TimelineAnimation<T> timeline,
  2. int index,
  3. double t
)
override

Computes the value for this keyframe at the given progress.

Parameters

  • timeline - The parent timeline animation.
  • index - The index of this keyframe in the timeline.
  • t - The local progress through this keyframe (0.0 to 1.0).

Returns

The computed value of type T at the given progress.

Implementation

@override
T compute(TimelineAnimation<T> timeline, int index, double t) {
  return timeline.lerp(from!, to!, t)!;
}