initials property

String initials
final

User initials or text to display in the avatar.

Primary fallback content when no image is provided via provider or when image loading fails. Should typically contain user's initials or a short representative text.

Implementation

final String initials;