ButtonStyleOverrideData class

Data class holding button style override delegates.

ButtonStyleOverrideData is used internally by ButtonStyleOverride to pass style override delegates through the widget tree via the Data inherited widget system. It stores optional delegates for each button style property.

This class is typically not used directly by application code; instead, use ButtonStyleOverride widget to apply style overrides.

Constructors

ButtonStyleOverrideData({ButtonStatePropertyDelegate<Decoration>? decoration, ButtonStatePropertyDelegate<MouseCursor>? mouseCursor, ButtonStatePropertyDelegate<EdgeInsetsGeometry>? padding, ButtonStatePropertyDelegate<TextStyle>? textStyle, ButtonStatePropertyDelegate<IconThemeData>? iconTheme, ButtonStatePropertyDelegate<EdgeInsetsGeometry>? margin})
Creates button style override data with the specified delegates.
const

Properties

decoration ButtonStatePropertyDelegate<Decoration>?
Optional decoration override delegate.
final
hashCode int
The hash code for this object.
no setteroverride
iconTheme ButtonStatePropertyDelegate<IconThemeData>?
Optional icon theme override delegate.
final
margin ButtonStatePropertyDelegate<EdgeInsetsGeometry>?
Optional margin override delegate.
final
mouseCursor ButtonStatePropertyDelegate<MouseCursor>?
Optional mouse cursor override delegate.
final
padding ButtonStatePropertyDelegate<EdgeInsetsGeometry>?
Optional padding override delegate.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle ButtonStatePropertyDelegate<TextStyle>?
Optional text style override delegate.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override