ChatTailTheme class

Defines the theme for the tail of a ChatBubble.

Inheritance

Constructors

ChatTailTheme({AxisDirectional? position, Size? size, BorderRadiusGeometry? borderRadius, double? tailRadius, TailBehavior? tailBehavior})
Creates a ChatTailTheme.
const

Properties

borderRadius BorderRadiusGeometry?
The border radius of the bubble when a tail is present.
final
hashCode int
The hash code for this object.
no setteroverride
position AxisDirectional?
The position of the tail relative to the bubble.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
The size of the tail.
final
tailBehavior TailBehavior?
The behavior determining when to show the tail.
final
tailRadius double?
The radius of the tail's curve.
final

Methods

copyWith({ValueGetter<AxisDirectional>? position, ValueGetter<Size>? size, ValueGetter<BorderRadiusGeometry>? borderRadius, ValueGetter<double>? tailRadius, ValueGetter<TailBehavior>? tailBehavior}) ChatTailTheme
Creates a copy of this theme with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override