surfaceBlur property
Optional blur amount override for the command palette surface backdrop.
When provided, overrides the theme's default surface blur.
Implementation
final double? surfaceBlur;
Optional blur amount override for the command palette surface backdrop.
When provided, overrides the theme's default surface blur.
final double? surfaceBlur;