ComponentThemeData class abstract
A base class for component-specific theme data.
This class is used as a base class for component-specific theme data, whether as super class or as interface.
- Implementers
- AccordionTheme
- AlertTheme
- AutoCompleteTheme
- AvatarTheme
- BadgeTheme
- BasicTheme
- BreadcrumbTheme
- ButtonTheme
- CalendarTheme
- CardImageTheme
- CardTheme
- CarouselTheme
- ChatGroupTheme
- ChatTailTheme
- ChatTheme
- CheckboxTheme
- ChipInputTheme
- ChipTheme
- CircularProgressIndicatorTheme
- CodeSnippetTheme
- CollapsibleTheme
- ColorInputTheme
- ColorPickerTheme
- ContextMenuTheme
- DatePickerTheme
- DividerTheme
- DotIndicatorTheme
- DrawerTheme
- DropdownMenuTheme
- FocusOutlineTheme
- FormattedInputTheme
- HoverCardTheme
- IconContainerTheme
- InputOTPTheme
- KeyboardShortcutTheme
- LinearProgressIndicatorTheme
- MediaQueryVisibilityTheme
- MenubarTheme
- MenuPopupTheme
- MenuTheme
- ModalBackdropTheme
- MultipleChoiceTheme
- NavigationBarTheme
- NavigationMenuTheme
- NumberTickerTheme
- OutlinedContainerTheme
- OverflowMarqueeTheme
- PaginationTheme
- PhoneInputTheme
- ProgressTheme
- RadioCardTheme
- RadioTheme
- RefreshTriggerTheme
- ResizableDraggerTheme
- ResizableTableTheme
- ScaffoldTheme
- ScrollableClientTheme
- ScrollbarTheme
- SelectableTextTheme
- SelectTheme
- SkeletonTheme
- SliderTheme
- StageContainerTheme
- StarRatingTheme
- StepperTheme
- StepsTheme
- SwiperTheme
- SwitchTheme
- TabContainerTheme
- TableTheme
- TabListTheme
- TabPaneTheme
- TabsTheme
- TextFieldTheme
- TimelineTheme
- TimePickerTheme
- ToastTheme
- TooltipTheme
- TrackerTheme
- TreeTheme
- WindowTheme
Constructors
- ComponentThemeData()
-
Creates a ComponentThemeData.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited