activeColor property
Color of the switch when in the active (on) state.
If null, uses the theme's primary color.
Implementation
final Color? activeColor;
Color of the switch when in the active (on) state.
If null, uses the theme's primary color.
final Color? activeColor;