DebounceController class

A controller to debounce or throttle a callback.

Inheritance

Constructors

DebounceController()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isActive bool
Whether the controller is active.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
cancel() → void
Cancel the debounce or throttle. The callback will not be called.
debounce<T>(DebounceCallback<T> callback, {Duration duration = const Duration(milliseconds: 300), DebounceResultConsumer<T>? consumer, DebounceErrorConsumer? errorConsumer}) → void
Debounce a callback.
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
throttle<T>(DebounceCallback<T> callback, {Duration duration = const Duration(milliseconds: 300), DebounceResultConsumer<T>? consumer, DebounceErrorConsumer? errorConsumer}) → void
Throttle a callback.
throttleFuture<T>(DebounceCallback<T> callback, {DebounceResultConsumer<T>? consumer, DebounceErrorConsumer? errorConsumer}) → void
Throttle a callback. Instead of waiting for the duration to call the callback, it will wait if the previous callback is still running.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited