DurationPart enum

Represents a part of a duration (day, hour, minute, or second).

Inheritance
Available extensions

Values

day → const DurationPart

Day component.

const DurationPart(_getDurationDay, _computeDurationDayValueRange)
hour → const DurationPart

Hour component.

const DurationPart(_getDurationHour, _computeDurationHourValueRange)
minute → const DurationPart

Minute component.

const DurationPart(_getDurationMinute, _computeDurationMinuteValueRange)
second → const DurationPart

Second component.

const DurationPart(_getDurationSecond, _computeDurationSecondValueRange)

Properties

computeValueRange → (int?, int?) Function(Map<DurationPart, int> values)
Function that computes the valid value range for this component.
final
getter int Function(Duration duration)
Function that extracts the duration component value from a Duration.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DurationPart>
A constant List of the values in this enum, in order of their declaration.