child property
The widget subtree containing form fields.
This child widget should contain the form fields and other UI elements that participate in the form. Form fields within this subtree automatically register with this Form instance.
Implementation
final Widget child;