ItemPickerLayout class abstract
Abstract base class for item picker layout strategies.
Defines how items are displayed in an item picker, such as in a list or grid. Provides factory constants for common layouts.
See also:
- ListItemPickerLayout, which displays items in a vertical list.
- GridItemPickerLayout, which displays items in a grid.
- Implementers
Constructors
- ItemPickerLayout()
-
Creates an ItemPickerLayout.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context, ItemChildDelegate items, ItemPickerBuilder builder) → Widget - Builds the widget for displaying items.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- grid → const GridItemPickerLayout
- A grid layout for item pickers (4 columns by default).
- list → const ListItemPickerLayout
- A list layout for item pickers.