ListChange<T> class abstract

Base class for list modification operations.

Extend this class to create custom list change types. Each change implements apply to modify a list in a specific way.

Implementers

Constructors

ListChange()
Creates a ListChange.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(List<T> list) → void
Applies this change to the given list.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited