MappedValueNotifier<T, R> class

A ValueListenable that maps the value of another ValueListenable.

Inheritance
Available extensions

Constructors

MappedValueNotifier(ValueListenable<T> _notifier, R _mapper(T value))
Constructs a MappedValueNotifier with the given ValueListenable and mapper function.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → R
The current value of the object.
no setteroverride

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object notifies its listeners.
override
map<R>(R mapper(T value)) ValueListenable<R>

Available on ValueListenable<T>, provided by the ValueListenableExtension extension

Returns a read-only view of the ValueListenable.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited