MenuOverlayHandler class
Overlay handler specialized for menu popover display.
Delegates to an OverlayManager to show menu popovers with appropriate positioning, transitions, and dismissal behavior.
- Inheritance
-
- Object
- OverlayHandler
- MenuOverlayHandler
Constructors
- MenuOverlayHandler(OverlayManager manager)
-
Creates a menu overlay handler.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- manager → OverlayManager
-
The overlay manager handling menu display.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show<
T> ({required BuildContext context, required AlignmentGeometry alignment, required WidgetBuilder builder, Offset? position, AlignmentGeometry? anchorAlignment, PopoverConstraint widthConstraint = PopoverConstraint.flexible, PopoverConstraint heightConstraint = PopoverConstraint.flexible, Key? key, bool rootOverlay = true, bool modal = true, bool barrierDismissable = true, Clip clipBehavior = Clip.none, Object? regionGroupId, Offset? offset, AlignmentGeometry? transitionAlignment, EdgeInsetsGeometry? margin, bool follow = true, bool consumeOutsideTaps = true, Anchor? anchor, ValueChanged< PopoverOverlayWidgetState> ? onTickFollow, bool allowInvertHorizontal = true, bool allowInvertVertical = true, bool dismissBackdropFocus = true, Duration? showDuration, Duration? dismissDuration, OverlayBarrier? overlayBarrier}) → OverlayCompleter<T?> -
Shows an overlay with the specified configuration.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited