ResizableData class

Data class providing information about a resizable panel's orientation.

Used internally to pass layout direction information through the widget tree.

Constructors

ResizableData(Axis direction)
Creates ResizableData with the specified direction.

Properties

direction Axis
The axis direction of the resizable panel (horizontal or vertical).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited