SelectionPosition enum
Represents the visual position of a selected item within a group.
Used to determine border radius styling for selected tree items when multiple consecutive items are selected.
Values
- start → const SelectionPosition
-
First item in a selection group.
- middle → const SelectionPosition
-
Middle item in a selection group.
- end → const SelectionPosition
-
Last item in a selection group.
- single → const SelectionPosition
-
Single selected item (not part of a group).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SelectionPosition> - A constant List of the values in this enum, in order of their declaration.