value property
The current value of the object. When the value changes, the callbacks registered with addListener will be invoked.
Implementation
@override
Set<T> get value => UnmodifiableSetView<T>(_set);
The current value of the object. When the value changes, the callbacks registered with addListener will be invoked.
@override
Set<T> get value => UnmodifiableSetView<T>(_set);