ShadcnPointArcTween class

A custom tween for animating points along an arc.

This tween creates curved motion between two points, useful for creating natural-looking animations.

Inheritance

Constructors

ShadcnPointArcTween({Offset? begin, Offset? end})
Creates a point arc tween.

Properties

begin Offset?
The value this variable has at the beginning of the animation.
getter/setter pairinherited-getteroverride-setter
beginAngle double?
Gets the starting angle of the arc in radians.
no setter
center Offset?
Gets the center point of the arc between begin and end.
no setter
end Offset?
The value this variable has at the end of the animation.
getter/setter pairinherited-getteroverride-setter
endAngle double?
Gets the ending angle of the arc in radians.
no setter
hashCode int
The hash code for this object.
no setterinherited
radius double?
Gets the radius of the arc between begin and end.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animate(Animation<double> parent) Animation<Offset>
Returns a new Animation that is driven by the given animation but that takes on values determined by this object.
inherited
chain(Animatable<double> parent) Animatable<Offset>
Returns a new Animatable whose value is determined by first evaluating the given parent and then evaluating this object at the result.
inherited
evaluate(Animation<double> animation) Offset
The current value of this object for the given Animation.
inherited
lerp(double t) Offset
Returns the value this variable has at the given animation clock value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transform(double t) Offset
Returns the interpolated value for the current value of the given animation.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited