StaticPart class

A part that displays static, non-editable text.

Inheritance

Constructors

StaticPart(String text)
Creates a StaticPart with the specified static text.
const

Properties

canHaveValue bool
Whether this part can hold a value.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
part InputPart
Returns this part.
no setterinherited
partKey String
A unique key identifying this part.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The static text to display.
final
value String?
The current value of this part, or null if it doesn't hold a value.
no setterinherited

Methods

build(BuildContext context, FormattedInputData data) Widget
Builds the widget for this part.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
withValue(String value) FormattedValuePart
Creates a copy of this part with the specified value.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override