StepsTheme class

Theme for Steps.

Inheritance

Constructors

StepsTheme({double? indicatorSize, double? spacing, Color? indicatorColor, double? connectorThickness})
Creates a StepsTheme.
const

Properties

connectorThickness double?
Thickness of the connector line.
final
hashCode int
The hash code for this object.
no setteroverride
indicatorColor Color?
Color of the indicator and connector line.
final
indicatorSize double?
Diameter of the step indicator circle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double?
Gap between the indicator and the step content.
final

Methods

copyWith({ValueGetter<double?>? indicatorSize, ValueGetter<double?>? spacing, ValueGetter<Color?>? indicatorColor, ValueGetter<double?>? connectorThickness}) StepsTheme
Creates a copy of this theme with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override