inactiveThumbColor property

Color? inactiveThumbColor
final

Color of the switch thumb when in the inactive/off state.

Applied to the circular thumb element when the switch is toggled off. When null, uses a contrasting color against the inactive track.

Implementation

final Color? inactiveThumbColor;