TabContainerData class

Internal data class holding tab container state and callbacks.

Provides context information to child tabs including the current selection state, tab index, and selection callback. Used internally by the tab system to coordinate between container and children.

Accessed via TabContainerData.of from within tab child widgets.

Constructors

TabContainerData({required int index, required int selected, required ValueChanged<int>? onSelect, required TabChildBuilder childBuilder})
Creates tab container data.

Properties

childBuilder TabChildBuilder
Builder function for wrapping tab child content.
final
hashCode int
The hash code for this object.
no setteroverride
index int
The index of this tab within the container (0-indexed).
final
onSelect ValueChanged<int>?
Callback to invoke when this tab should be selected.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected int
The index of the currently selected tab.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

of(BuildContext context) TabContainerData
Retrieves the nearest TabContainerData from the widget tree.