backgroundColor property

Color? backgroundColor
final

Background color for the tab pane content area and active tabs.

Type: Color?. If null, uses the theme's card color. This provides the background for both the main content area and highlighted tabs.

Implementation

final Color? backgroundColor;