TailBehavior class abstract

Defines when a tail should be shown on a ChatBubble.

Constructors

TailBehavior()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrapWithTail(ChatBubbleData data) bool
Determines whether the bubble at the given index should have a tail.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

first → const _ChatTailBehavior
Shows a tail on the first bubble in a group.
last → const _ChatTailBehavior
Shows a tail on the last bubble in a group.
middle → const _ChatTailBehavior
Shows a tail on the middle bubble in a group.