ThemeMode enum

Determines which theme mode to use.

  • system: Follow system theme preference
  • light: Always use light theme
  • dark: Always use dark theme
Inheritance
Available extensions

Values

system → const ThemeMode

Follow the system theme (light or dark based on device settings).

light → const ThemeMode

Always use light theme.

dark → const ThemeMode

Always use dark theme.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ThemeMode>
A constant List of the values in this enum, in order of their declaration.