UnaryOperator<T> typedef
UnaryOperator<T> =
T Function(T value)
A function that takes a value of type T and returns a value of type T.
Implementation
typedef UnaryOperator<T> = T Function(T value);
A function that takes a value of type T and returns a value of type T.
typedef UnaryOperator<T> = T Function(T value);