operator & method

Validator<T> operator &(
  1. Validator<T> other
)

Combines this validator with another using AND logic (alias for combine).

This operator provides a convenient syntax for combining validators where both must pass for validation to succeed.

Example:

final validator = RequiredValidator<String>() & EmailValidator();

Implementation

Validator<T> operator &(Validator<T> other) {
  return combine(other);
}