Anchor class abstract
Describes an anchor point that overlays (popovers, menus, tooltips) can position themselves relative to, and optionally track as it moves.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext context) → Anchor -
Fills in any defaults this anchor needs from
context— the BuildContext of whatevershow()call is about to use this anchor. -
subscribe(
) → AnchorSubscription - Starts a live subscription to this anchor's position/visibility.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited