AutoCompleteIntent class
An intent representing an autocomplete suggestion selection.
Used by the autocomplete system to handle suggestion selections with different modes of completion.
Constructors
- AutoCompleteIntent(String suggestion, AutoCompleteMode mode)
-
Creates an autocomplete intent with the specified suggestion and mode.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → AutoCompleteMode
-
The mode determining how the completion should be applied.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestion → String
-
The suggestion text to be completed.
final
Methods
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited