AxisDirectional enum
Defines a direction along an axis, either vertical or horizontal.
This is similar to AxisDirection but includes support for directional values (start/end) that resolve based on TextDirection.
Values
- up → const AxisDirectional
-
Up direction.
- down → const AxisDirectional
-
Down direction.
- start → const AxisDirectional
-
Start direction (left in LTR, right in RTL).
- end → const AxisDirectional
-
End direction (right in LTR, left in RTL).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - reversed → AxisDirectional
-
Returns the reversed direction.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
TextDirection textDirection) → AxisDirection - Resolves the directional axis to a concrete AxisDirection based on the text direction.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AxisDirectional> - A constant List of the values in this enum, in order of their declaration.