AxisInsets class
Insets along an axis with support for directionality.
- Inheritance
-
- Object
- AxisInsetsGeometry
- AxisInsets
Constructors
- AxisInsets({required double start, required double end})
-
Creates an AxisInsets.
const
Properties
- direction → TextDirection?
-
The text direction, if any.
final
- end → double
-
The end value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → double
-
The start value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
TextDirection textDirection) → AxisInsets -
Resolves the insets to a concrete AxisInsets based on the text direction.
override
-
resolveValue(
Axis axis) → ({double end, double start}) - Resolves the start and end values for a specific axis.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited