next property
CalendarView
get
next
Returns a view for the next month.
Advances to the next month, rolling over to January of the next year if the current month is December.
Implementation
CalendarView get next {
if (month == 12) {
return CalendarView(year + 1, 1);
}
return CalendarView(year, month + 1);
}