DividerProperties class
Immutable properties for divider appearance.
DividerProperties stores the visual characteristics of a divider, including color, thickness, and indentation. This class is used for theme interpolation and default value management.
All properties are required and non-nullable.
Constructors
- DividerProperties({required Color color, required double thickness, required double indent, required double endIndent})
-
Creates divider properties with the specified values.
const
Properties
- color → Color
-
The color of the divider line.
final
- endIndent → double
-
The amount of empty space to the trailing edge of the divider.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indent → double
-
The amount of empty space to the leading edge of the divider.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thickness → double
-
The thickness of the divider line in logical pixels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
DividerProperties a, DividerProperties b, double t) → DividerProperties - Linearly interpolates between two DividerProperties objects.