InputLeadingFeature class
Adds a custom widget to the leading (left) side of the input field.
Allows you to place any widget before the input text, such as icons, labels, or other decorative elements.
Example:
TextField(
features: [
InputLeadingFeature(
Icon(Icons.search),
),
],
)
- Inheritance
-
- Object
- InputFeature
- InputLeadingFeature
Constructors
- InputLeadingFeature(Widget prefix, {InputFeatureVisibility visibility = InputFeatureVisibility.always, bool skipFocusTraversal = true})
-
Creates an InputLeadingFeature.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- prefix → Widget
-
The widget to display on the leading side.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipFocusTraversal → bool
-
Whether to skip this feature in focus traversal.
finalinherited
- visibility → InputFeatureVisibility
-
Visibility mode for this input feature.
finalinherited
Methods
-
createState(
) → InputFeatureState< InputFeature> -
Creates the state for this input feature.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited