IntrinsicComputer typedef
Function that computes intrinsic dimensions for a render box.
Used internally during table layout to calculate natural sizes of cells when using intrinsic sizing modes.
Implementation
typedef IntrinsicComputer = double Function(RenderBox child, double extent);