LinkedAnchor class
An Anchor resolved dynamically through an OverlayAnchorRegistry, via the key an OverlayAnchor widget was registered with.
The registry is resolved from the BuildContext passed to a show() call
(see resolve) so the anchor connects to the nearest OverlayAnchorScope;
pass registry explicitly to target a specific one.
Constructors
- LinkedAnchor(Object key, {OverlayAnchorRegistry? registry})
-
Creates a LinkedAnchor.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Object
-
The registry key, matching an OverlayAnchor.anchor.
final
- registry → OverlayAnchorRegistry?
-
The registry this anchor is bound to. When null it is filled in by
resolve from the calling context's nearest OverlayAnchorScope.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext context) → Anchor -
Fills in any defaults this anchor needs from
context— the BuildContext of whatevershow()call is about to use this anchor.override -
subscribe(
) → AnchorSubscription -
Starts a live subscription to this anchor's position/visibility.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited