NoBackdropTransform class
A BackdropTransform that leaves the backdrop untouched.
- Inheritance
-
- Object
- BackdropTransform
- NoBackdropTransform
Constructors
- NoBackdropTransform()
-
Creates an identity backdrop transform.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveExtraSize(
Size size, double t, {bool isRoot = true}) → Size -
The amount of space (per axis) freed by this transform for a backdrop of
sizeat progresst. Returns Size.zero when nothing is freed.override -
toString(
) → String -
A string representation of this object.
inherited
-
wrapBackdrop(
BuildContext context, Widget child, double t, {bool isRoot = true}) → Widget -
Wraps
child(the backdrop content) with the visual transform for progresst(0 = closed, 1 = fully open).override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited