OverlayHandler class abstract
Abstract handler for managing overlay presentation and lifecycle.
Provides common interface for different overlay types (popover, sheet, dialog) with customizable display, positioning, and interaction behavior.
Constructors
- OverlayHandler()
-
Creates an OverlayHandler.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show<
T> ({required BuildContext context, required AlignmentGeometry alignment, required WidgetBuilder builder, Offset? position, AlignmentGeometry? anchorAlignment, PopoverConstraint widthConstraint = PopoverConstraint.flexible, PopoverConstraint heightConstraint = PopoverConstraint.flexible, Key? key, bool rootOverlay = true, bool modal = true, bool barrierDismissable = true, Clip clipBehavior = Clip.none, Object? regionGroupId, Offset? offset, AlignmentGeometry? transitionAlignment, EdgeInsetsGeometry? margin, bool follow = true, bool consumeOutsideTaps = true, Anchor? anchor, ValueChanged< PopoverOverlayWidgetState> ? onTickFollow, bool allowInvertHorizontal = true, bool allowInvertVertical = true, bool dismissBackdropFocus = true, Duration? showDuration, Duration? dismissDuration, OverlayBarrier? overlayBarrier}) → OverlayCompleter<T?> - Shows an overlay with the specified configuration.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- dialog → const OverlayHandler
- Default dialog overlay handler.
- popover → const OverlayHandler
- Default popover overlay handler.
- sheet → const OverlayHandler
- Default sheet overlay handler.