OverlayManagerAsTooltipOverlayHandler class
Overlay handler that delegates tooltip display to an OverlayManager.
This handler integrates tooltips with the overlay management system, allowing tooltips to be displayed through the overlay manager's tooltip-specific display logic. This ensures proper layering and lifecycle management within the overlay system.
- Inheritance
-
- Object
- OverlayHandler
- OverlayManagerAsTooltipOverlayHandler
Constructors
- OverlayManagerAsTooltipOverlayHandler({required OverlayManager overlayManager})
-
Creates an OverlayManagerAsTooltipOverlayHandler.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- overlayManager → OverlayManager
-
The overlay manager instance to use for displaying tooltips.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show<
T> ({required BuildContext context, required AlignmentGeometry alignment, required WidgetBuilder builder, Offset? position, AlignmentGeometry? anchorAlignment, PopoverConstraint widthConstraint = PopoverConstraint.flexible, PopoverConstraint heightConstraint = PopoverConstraint.flexible, Key? key, bool rootOverlay = true, bool barrierDismissable = true, bool modal = true, Clip clipBehavior = Clip.none, Object? regionGroupId, Offset? offset, AlignmentGeometry? transitionAlignment, EdgeInsetsGeometry? margin, bool follow = true, bool consumeOutsideTaps = true, Anchor? anchor, ValueChanged< PopoverOverlayWidgetState> ? onTickFollow, bool allowInvertHorizontal = true, bool allowInvertVertical = true, bool dismissBackdropFocus = true, Duration? showDuration, Duration? dismissDuration, OverlayBarrier? overlayBarrier}) → OverlayCompleter<T?> -
Shows an overlay with the specified configuration.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited