SelectData class
Data class holding select dropdown state and configuration.
Contains selection state, callbacks, and display options for select popups.
Constructors
-
SelectData({required bool? autoClose, required Predicate<
Object?> isSelected, required SelectValueChanged<Object?> onChanged, required bool hasSelection, required bool enabled}) -
Creates select data.
const
Properties
- autoClose → bool?
-
Whether to automatically close the popup after selection.
final
- enabled → bool
-
Whether the select is enabled for interaction.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasSelection → bool
-
Whether any items are currently selected.
final
-
isSelected
→ Predicate<
Object?> -
Predicate to check if a value is currently selected.
final
-
onChanged
→ SelectValueChanged<
Object?> -
Callback invoked when selection changes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override