SelectValueChanged<T> typedef
Callback type for handling selection changes in select components.
Returns true if the change was successful, false otherwise.
Implementation
typedef SelectValueChanged<T> = bool Function(T value, bool selected);