SheetOverlayHandler class
Overlay handler specialized for sheet-style overlays.
Provides a simplified API for showing sheet overlays (bottom sheets, side sheets, etc.) with standard positioning and barrier behavior.
- Inheritance
-
- Object
- OverlayHandler
- SheetOverlayHandler
Constructors
- SheetOverlayHandler({OverlayPosition position = OverlayPosition.bottom, Color? barrierColor})
-
Creates a sheet overlay handler.
const
Properties
- barrierColor → Color?
-
Optional barrier color for the modal backdrop.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- position → OverlayPosition
-
Position where the sheet appears.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show<
T> ({required BuildContext context, required AlignmentGeometry alignment, required WidgetBuilder builder, Offset? position, AlignmentGeometry? anchorAlignment, PopoverConstraint widthConstraint = PopoverConstraint.flexible, PopoverConstraint heightConstraint = PopoverConstraint.flexible, Key? key, bool rootOverlay = true, bool modal = true, bool barrierDismissable = true, Clip clipBehavior = Clip.none, Object? regionGroupId, Offset? offset, AlignmentGeometry? transitionAlignment, EdgeInsetsGeometry? margin, bool follow = true, bool consumeOutsideTaps = true, ValueChanged< PopoverOverlayWidgetState> ? onTickFollow, bool allowInvertHorizontal = true, bool allowInvertVertical = true, bool dismissBackdropFocus = true, Duration? showDuration, Duration? dismissDuration, OverlayBarrier? overlayBarrier, LayerLink? layerLink}) → OverlayCompleter<T?> -
Shows an overlay with the specified configuration.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
isSheetOverlay(
BuildContext context) → bool - Checks if the current context is within a sheet overlay.