SortableChildBuilderDelegate<T> class
A delegate that builds items on demand.
Creates items using a builder function rather than from a fixed list. Useful for large or lazily-generated item sets.
- Inheritance
-
- Object
- SortableListDelegate<
T> - SortableChildBuilderDelegate
Constructors
-
SortableChildBuilderDelegate({int? itemCount, required SortableItemBuilder<
T> builder}) -
Creates a SortableChildBuilderDelegate.
const
Properties
-
builder
→ SortableItemBuilder<
T> -
Builder function for creating items.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemCount → int?
-
The number of items, or
nullfor infinite lists.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getItem(
BuildContext context, int index) → T -
Retrieves the item at the specified
index.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited