StageContainerTheme class
Theme configuration for StageContainer responsive behavior.
Defines default breakpoint strategy and padding for stage containers.
- Inheritance
-
- Object
- ComponentThemeData
- StageContainerTheme
Constructors
- StageContainerTheme({StageBreakpoint? breakpoint, EdgeInsets? padding})
-
Creates a StageContainerTheme.
const
Properties
- breakpoint → StageBreakpoint?
-
The breakpoint strategy to use.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- padding → EdgeInsets?
-
Default padding for the container.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ValueGetter< StageBreakpoint?> ? breakpoint, ValueGetter<EdgeInsets?> ? padding}) → StageContainerTheme - Creates a copy of this theme with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override