StagedBreakpoint class
A breakpoint that uses predefined stage values.
Maps container widths to the nearest breakpoint value from a list. Commonly used for responsive design with specific breakpoints like mobile (576), tablet (768), desktop (992), etc.
- Implemented types
Constructors
-
StagedBreakpoint(List<
double> breakpoints) -
Creates a StagedBreakpoint with custom breakpoints.
const
- StagedBreakpoint.defaultBreakpoints()
-
Creates a StagedBreakpoint with default responsive breakpoints.
const
Properties
-
breakpoints
→ List<
double> -
List of breakpoint width values in ascending order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxSize → double
-
Maximum allowed size constraint.
no setteroverride
- minSize → double
-
Minimum allowed size constraint.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getMaxWidth(
double width) → double -
Calculates the maximum width for the given container
width.override -
getMinWidth(
double width) → double -
Calculates the minimum width for the given container
width.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited