TableRow class
Represents a row in a table.
Contains a list of cells and optional styling for all cells in the row. Can be marked as selected to highlight the entire row.
Example:
TableRow(
cells: [
TableCell(child: Text('Cell 1')),
TableCell(child: Text('Cell 2')),
],
selected: true,
cellTheme: TableCellTheme(...),
)
- Implementers
Constructors
Properties
-
cells
→ List<
TableCell> -
The cells contained in this row.
final
- cellTheme → TableCellTheme?
-
Theme applied to all cells in this row.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
Whether this row is selected.
final
Methods
-
buildDefaultTheme(
BuildContext context) → TableCellTheme - Builds the default theme for cells in this row.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override